rm(list=ls())
T1<-proc.time()
# Parameter values defined here
#################################### Parameters ##########################################
## Selection Parameters
SourceTheta<-0 # Optimum phenotype in source
SinkTheta<-c(1.75)# Optimum phenotype in sink, can take multiple values to loop through
Ve=0.5 # Environmental component of phenotypic variance
w=1.5 # Controls strength of stabilizing selection

## Demographic Parameters
K<-100 # Carrying-capacity
N<-K # Starting population size in source
B<-10 # Maternal gametes per individual
Nmax<-2*K*B # Maximum number of individuals possible
Ne<-round((2*B*N)/((2*B)-1),4)  # effective population size 
I=c(0) # Proportion of pollen pool from Source population, can take multiple values to loop through
NumCol=10 # Number of colonists to start sink population in generation m

## Genetic Parameters
NlociQT<-10 # Number loci for quantitative trait
NalleleQT<-NlociQT*2
NlociID<-10 # Number loci for deleterious mutations
NalleleID<-NlociID*2
Nloci<-NlociQT + NlociID # Number Loci total
Nallele<-Nloci*2 # Number Alleles total
DomIndex<-cbind((NalleleQT+1):(NalleleQT+NlociID),(NalleleQT+NlociID+1):Nallele) # Used to find homozygotes for ID loci
LocusIndex<-cbind(c(1:NlociQT,(NalleleQT+1):(NalleleQT+NlociID)),c((NlociQT+1):NalleleQT,(NalleleQT+NlociID+1):Nallele))
mu=0.001 # per locus per haplotype mutation rate
alpha=0.0025 # Mutational variance
Vg<-(4*Nloci*mu*alpha*Ne)/(1+((alpha*Ne)/w)) # SHC genetic variance, eq.14 Burger and Lynch 1995
sel<-c(0) # Selection coefficient for deleterious mutation, can take multiple values to loop through
dom<-c(0)  # dominance coefficient for deleterious mutation, can take multiple values to loop through

## Mating System Parameters
Pself<-c(0,0.1) # Proportion of ovules fertilized by self pollen in sink environment, can take multiple values to loop through
PollProb<-c(1,0.7,0.5,0.3)# Probability of an ovule receiving outcrossed pollen (determines pollen limitation), can take multiple values to loop through

## Convert all variances to standard deviations for rnorm
SDg<-round(sqrt(Vg),4)
SDe<-round(sqrt(Ve),4)
SDm<-round(sqrt(alpha),4)
#########################################################################################
# Define stabilizing selection function
Fitness<-function(Pheno,Theta,Mut){ 
  ft<-round((exp(-((Pheno-Theta)^2)/w))-Mut,4)
  ft[ft<0]<-0
  ft
}

# Define phenotype function
Phenotype<-function(matrix,Ind){
  if(length(Ind)==1){
    Geno<-sum(matrix[Ind,1:NalleleQT])
  } else {Geno<-rowSums(matrix[Ind,1:NalleleQT])}
  N<-length(Geno)
  EnvEffect<-round(rnorm(N,0,SDe),4)
  Geno+EnvEffect
}

# Define genetic load function
Load<-function(matrix,Ind){
  HomoIndex<-matrix[Ind,DomIndex[,1]]+matrix[Ind,DomIndex[,2]]
  if(length(Ind)==1){
    sum(ifelse(HomoIndex==2,sel[l],dom[l]*sel[l]*HomoIndex))
  } else {rowSums(ifelse(HomoIndex==2,sel[l],dom[l]*sel[l]*HomoIndex))}
}

# Define functions to make gametes
gametes<-function(matrix,Ind,N){
  IndAssortment<-sample(1:2,N*Nloci,replace=TRUE)
  Index1<-cbind(rep(1:Nloci,N),IndAssortment)
  Index2<-cbind(rep(Ind,each=Nloci),LocusIndex[Index1])
  matrix(matrix[Index2],nrow=N,ncol=Nloci,byrow=TRUE)
}

# Define function to impose mutation randomly on loci in zygotes
Mutation<-function(matrix){
  N<-dim(matrix)[1]
  Mut<-matrix(rbinom(N*Nallele,size=1,prob=mu),nrow=N,ncol=dim(matrix)[2]-1)
  MutVec<-which(Mut==1)
  Nmut<-length(MutVec)
  if(Nmut>0){
    x<-NalleleQT*N
    matrix[MutVec]<-ifelse(MutVec<=x,matrix[MutVec]+round(rnorm(Nmut,0,SDm),4),max(matrix[MutVec],1))
  }
  matrix
}

# Obligate self-fertilization
MatingSF<-function(sperm,egg,Nsf,Ind){
  Nparent<-length(Ind)
  Offspring<-matrix(0,nrow=Nparent*Nsf,ncol=(Nallele+1))
  Individual<-seq(1,(Nparent*Nsf),Nparent)
  RowIndex<-rep((1:Nparent-1),each=Nsf)
  
  SFrows<-matrix(rep(Individual,Nparent)+RowIndex,
                 nrow=Nparent,ncol=Nsf,byrow=TRUE)
  
  Offspring[,LocusIndex[,2]]<-sperm[SFrows,]
  Offspring[,LocusIndex[,1]]<-egg[SFrows,]
  Offspring
}

# Obligate outcrossing
MatingOC<-function(sperm,egg,Noc,Ind,ImmPoll,ImmSperm){
  Nparent<-length(Ind)
  Noffspring<-sum(Noc)
  OCparent<-Nparent-1
  Offspring<-matrix(0,nrow=Noffspring,ncol=(Nallele+1))
  Individual<-seq(1,(Nparent*B),Nparent)
  Index<-rep(1:Nparent,Noc)
  RowIndex<-rep(0:OCparent,each=B)
  SFrows<-matrix(rep(Individual,Nparent)+RowIndex,
                 nrow=Nparent,ncol=B,byrow=TRUE)
  OCrows<-matrix(1:Nparent,nrow=Nparent,ncol=Nparent)
  diag(OCrows)<-0
  OCrows<-matrix(OCrows[OCrows>0],nrow=OCparent,ncol=Nparent)
  OCpollenCol<-unlist(lapply(Noc,function(n) sample(1:B,n)))
  OCpollenRow<-unlist(lapply(Noc,function(n) sample(1:OCparent,n,replace=TRUE)))
  OCpollen<-cbind(OCrows[cbind(OCpollenRow,Index)],OCpollenCol)
  SFeggCol<-unlist(lapply(Noc,function(n) sample(1:B,n)))  
  SFeggs<-cbind(Index,SFeggCol)
  Offspring[,LocusIndex[,1]]<-egg[SFrows[SFeggs],]
  Offspring[,LocusIndex[,2]]<-sperm[SFrows[OCpollen],]
  if (ImmPoll>0){ 
    PollenNumber<-rbinom(1,size=Noffspring,prob=ImmPoll) 
    Imm<-sample(row(ImmSperm),PollenNumber,replace=FALSE)
    Replace<-sample(row(OCpollen),PollenNumber,replace=FALSE)
    Offspring[Replace,LocusIndex[,2]]<-ImmSperm[Imm,]
  }
  Offspring
}

# Mixed mating
MatingMX<-function(sperm,egg,Noc,Nsf,Ind,ImmPoll,ImmSperm){
  Nparent<-length(Ind)
  OCparent<-Nparent-1
  Noffspring<-Noc+Nsf
  Ntotal<-sum(Noffspring)
  Offspring<-matrix(0,nrow=Ntotal,ncol=(Nallele+1))
  SFindex<-rep(1:Nparent,Nsf)
  OCindex<-rep(1:Nparent,Noc)
  Index<-c(OCindex,SFindex)
  Individual<-seq(1,(Nparent*B),Nparent)
  RowIndex<-rep(0:OCparent,each=B)
  SFrows<-matrix(rep(Individual,Nparent)+RowIndex,
                 nrow=Nparent,ncol=B,byrow=TRUE)
  SFeggCol<-unlist(lapply(Noffspring,function(n) sample(1:B,n)))  
  SFeggs<-cbind(Index,SFeggCol)
  Offspring[,LocusIndex[,1]]<-egg[SFrows[SFeggs],]
  SFpollenCol<-unlist(lapply(Nsf,function(n) sample(1:B,n)))
  SFpollen<-cbind(SFindex,SFpollenCol)
  OCrows<-matrix(1:Nparent,nrow=Nparent,ncol=Nparent)
  diag(OCrows)<-0
  OCrows<-matrix(OCrows[OCrows>0],nrow=OCparent,ncol=Nparent)
  OCpollenCol<-unlist(lapply(Noc,function(n) sample(1:B,n)))
  OCpollenRow<-unlist(lapply(Noc,function(n) sample(1:OCparent,n,replace=TRUE)))
  OCpollen<-cbind(OCrows[cbind(OCpollenRow,OCindex)],OCpollenCol)
  AllPollen<-rbind(OCpollen,SFpollen)
  Offspring[,LocusIndex[,2]]<-sperm[SFrows[AllPollen],]
  if (ImmPoll>0){ 
    PollenNumber<-rbinom(1,size=sum(Noc),prob=ImmPoll) 
    Imm<-sample(row(ImmSperm),PollenNumber,replace=FALSE)
    Replace<-sample(1:sum(Noc),PollenNumber,replace=FALSE)
    Offspring[Replace,LocusIndex[,2]]<-ImmSperm[Imm,]
  }
  Offspring
}

# Reproduction when only 1 individual in the population
MatingSOLO<-function(sperm,egg,Noc,Nsf,Ind,ImmSperm){
  Noffspring<-Noc+Nsf
  SFpollen<-matrix(sperm[sample(row(sperm),Nsf,replace=FALSE),],nrow=Nsf,ncol=Nloci)
  if (Pself[j]==1|Noc==0){ 
    Offspring<-matrix(0,nrow=Noffspring,ncol=Nallele)
    Offspring[1:Noffspring,LocusIndex[,2]]<-SFpollen 
    Offspring[1:Noffspring,LocusIndex[,1]]<-egg[Noffspring,]
    Offspring
  }
  if (Pself[j]<1&Noc>0){
    OCpollen<-matrix(ImmSperm[sample(row(ImmSperm),Noc,replace=FALSE),],ncol=Nloci,nrow=Noc)
    Offspring<-matrix(0,nrow=Noffspring,ncol=(Nallele+1))
    Offspring[1:Noffspring,LocusIndex[,2]]<-rbind(OCpollen,SFpollen)
    Offspring[1:Noffspring,LocusIndex[,1]]<-egg[1:Noffspring,]
    Offspring
  }
}

# Function to separately simulate selfed and outcrossed progeny to measure inbreeding depression
InbreedingDep<-function(matrix,Ind){
  Nparent<-length(Ind)
  OCparent<-Nparent-1
  ifelse(Nparent<10,N<-50,N<-B)
  Noffspring<-N*Nparent
  egg<-gametes(matrix,Ind,N=Noffspring)
  sperm<-gametes(matrix,Ind,N=Noffspring)
  OC<-matrix(0,nrow=Noffspring,ncol=Nallele)
  SF<-matrix(0,nrow=Noffspring,ncol=Nallele)
  Individual<-seq(1,(Nparent*N),Nparent)
  RowIndex<-rep(0:OCparent,each=N)
  Index<-rep(1:Nparent,each=N)
  SFrows<-matrix(rep(Individual,Nparent)+RowIndex,
                 nrow=Nparent,ncol=N,byrow=TRUE)
  SF[,LocusIndex[,2]]<-sperm[SFrows,]
  SF[,LocusIndex[,1]]<-egg[SFrows,]
  OC[,LocusIndex[,1]]<-egg[SFrows,]
  
  OCrows<-matrix(1:Nparent,nrow=Nparent,ncol=Nparent)
  diag(OCrows)<-0
  OCrows<-matrix(OCrows[OCrows>0],nrow=OCparent,ncol=Nparent)
  OCpollenRow<-as.vector(apply(OCrows,2,sample,N,replace=TRUE))
  OCpollenCol<-sample(1:N,Noffspring,replace=TRUE)
  OCpollen<-cbind(OCpollenRow,OCpollenCol)
  OC[,LocusIndex[,2]]<-sperm[SFrows[OCpollen],]
  
  OCgeno<-apply(OC[,1:NalleleQT],1,sum)
  SFgeno<-apply(SF[,1:NalleleQT],1,sum)
  if (sel[l]>0){
    OCmt<-Load(matrix=OC,Ind=row(OC))
    SFmt<-Load(matrix=SF,Ind=row(SF))
    OCfit<-Fitness(Pheno=OCgeno,Theta=SinkTheta[q],Mut=OCmt)
    SFfit<-Fitness(Pheno=SFgeno,Theta=SinkTheta[q],Mut=SFmt)
  } else {
    OCfit<-Fitness(Pheno=OCgeno,Theta=SinkTheta[q],Mut=0)
    SFfit<-Fitness(Pheno=SFgeno,Theta=SinkTheta[q],Mut=0)
  }
  c(round(1-(mean(SFfit)/mean(OCfit)),4),round(mean(OCfit),4),round(mean(SFfit),4))
}
############################################################################################
## Details for Simulations
R=400 # Number of replicate simulations for a given set of parameter values
T=2001 # Number of iterations (generations)
m=1000 # Generation to start sink population
TrackVec<-c(m+(1:50),seq(m+51,T,10)) # Vector of generations in which to record data
TrackVec2<-c(m+seq(2,51,5),T)
RowNum<-length(TrackVec)
RowNum2<-length(TrackVec2)
###############################################################################################
# Loop through pollen limitation values (PollProb)
for (y in 1:length(PollProb)){
  
  # Loop through sink optimum values (theta)
  for (q in 1:length(SinkTheta)){
    
    # Loop through mutational models (dom and sel)
    for (l in 1:length(sel)){
      
      # Loop through I values
      for (k in 1:length(I)){
        
        # Loop through Pself values
        for (j in 1:length(Pself)) {
          
          # Set up output matrices
          Output<-array(0,dim=c(RowNum,R,6),dimnames=list(1:RowNum,1:R,
                                                          c("PopSizeSink","GenoAvgSink","GenoVarSink","MutLoad", "MutLoadVar","Tadapt")))
          Output2<-array(0,dim=c(RowNum2,R,3),dimnames=list(1:RowNum2,1:R,
                                                            c("ID","OCfit","SFfit")))
          
          # Name column to keep track of alive individuals (1 = alive, 0 = dead)
          AliveCol<-Nallele+1
          
          # Set up initial alleles
          for (r in 1:R){
            L<-matrix(round(rnorm((NlociQT*5),SourceTheta,SDg),4),nrow=5,ncol=NlociQT) # Draw 5 alleles /locus
            Source<-matrix(0,N,Nallele+1) 
            LRow<-sample(1:5,NalleleQT*N,replace=TRUE) # randomly sample an allele for each locus
            LCol<-rep(rep(1:NlociQT,each=(N)),2)
            Source[1:N,1:NalleleQT]<-L[cbind(LRow,LCol)] # Draw genotypes to start source population
            Sink<-matrix(0,N,(Nallele+1))
            
            # All inidividuals in source start out alive
            Source[1:N,AliveCol]<-1
            
            ##### Evolution in source population
            for (t in 1:T){
              
              # Viability selection based on QT genotype and ID genotype
              AliveRowsSource<-which(Source[,AliveCol]==1)
              AliveNumSource<-as.integer(length(AliveRowsSource))
              mt<-Load(matrix=Source,Ind=AliveRowsSource)
              Z<-Phenotype(matrix=Source,Ind=AliveRowsSource)
              SurvProb<-Fitness(Pheno=Z,Theta=SourceTheta,Mut=mt)
              Source[AliveRowsSource,AliveCol]<-rbinom(AliveNumSource,size=1,prob=SurvProb)
              AliveRowsSource<-which(Source[,AliveCol]==1)
              AliveNumSource<-as.integer(length(AliveRowsSource))
              
              # Density dependence
              if (AliveNumSource>K){
                DensitySurvivors<-sample(AliveRowsSource,K,replace=FALSE)
                Source[,AliveCol]<-0  
                Source[DensitySurvivors,AliveCol]<-1
                AliveRowsSource<-which(Source[,AliveCol]==1)
                AliveNumSource<-as.integer(length(AliveRowsSource))
              }
              
              # Make gametes
              NoffspringSource<-B*AliveNumSource
              EggSource<-gametes(matrix=Source,Ind=AliveRowsSource,N=NoffspringSource)
              SpermSource<-gametes(matrix=Source,Ind=AliveRowsSource,N=NoffspringSource)
              
              # Mating
              OffspringVec<-rep(B,AliveNumSource)
              Source<-MatingOC(sperm=SpermSource,egg=EggSource,Noc=OffspringVec,Ind=AliveRowsSource,ImmPoll=0)
              Source[,AliveCol]<-1
              
              # Mutations occur randomly at each locus in next generation  
              Source<-Mutation(matrix=Source)
              
              # Seeds disperse to sink population in generation m
              if (t==m) {
                Col<-sample(row(Source),NumCol,replace=FALSE)
                Sink[1:NumCol,]<-Source[Col,]
                Source[Col,AliveCol]<-0 }
              
              ##### Evolution in sink population
              if (t>m){
                # Viability selection
                AliveRowsSink<-which(Sink[,AliveCol]==1)
                AliveNumSink<-as.integer(length(AliveRowsSink))
                mtSink<-Load(matrix=Sink,Ind=AliveRowsSink)
                ZSink<-Phenotype(matrix=Sink,Ind=AliveRowsSink)
                SurvProbSink<-Fitness(Pheno=ZSink,Theta=SinkTheta[q],Mut=mtSink)
                # record generation that sink reaches 0.5 fitness
                if (Output[1,r,6]==0){
                  MeanFit<-mean(SurvProbSink)
                  if (MeanFit>=0.5) {Output[1,r,6]<-(t-m)}
                }
                Sink[AliveRowsSink,AliveCol]<-rbinom(AliveNumSink,size=1,prob=SurvProbSink)
                AliveRowsSink<-which(Sink[,AliveCol]==1)
                AliveNumSink<-as.integer(length(AliveRowsSink))
                
                # Has population gone extinct after selection?
                if (AliveNumSink==0|AliveNumSink==1&Pself[j]==0&I[k]==0){
                  print(cat("Sink Extinction","Generation=",t,"Replicate=",r))
                  break  
                } 
                
                # Census population for variables of interest
                RowN<-which(TrackVec==t)
                if (length(RowN)==1){
                  Output[RowN,r,1]<-AliveNumSink
                  ifelse(AliveNumSink==1, MeanGenotypes<-sum(Sink[AliveRowsSink,1:NalleleQT]),
                         MeanGenotypes<-apply(Sink[AliveRowsSink,1:NalleleQT],1,sum))
                  Output[RowN,r,2]<-round(mean(MeanGenotypes),4)
                  Output[RowN,r,3]<-round(var(MeanGenotypes),4)
                  RowN2<-which(TrackVec2==t)
                  if (length(RowN2)==1){
                    if (AliveNumSink>1){
                      ID<-InbreedingDep(matrix=Sink,Ind=AliveRowsSink)
                      Output2[RowN2,r,1]<-ID[1]
                      Output2[RowN2,r,2]<-ID[2]
                      Output2[RowN2,r,3]<-ID[3]
                    } else if (AliveNumSink==1){Output2[RowN2,r,1:3]<-NA}
                  }
                  if (sel[l]>0){
                    Output[RowN,r,4]<-round(mean(mtSink[AliveRowsSink]),4)
                    Output[RowN,r,5]<-round(var(mtSink[AliveRowsSink]),4)
                  }
                }
                
                # Density dependence
                if (AliveNumSink>K){
                  DensitySurvivors<-sample(AliveRowsSink,K,replace=FALSE)
                  Sink[,AliveCol]<-0  
                  Sink[DensitySurvivors,AliveCol]<-1
                  AliveRowsSink<-which(Sink[,AliveCol]==1)
                  AliveNumSink<-as.integer(length(AliveRowsSink))
                }
                # Make gametes
                NoffspringSink<-B*AliveNumSink
                EggSink<-gametes(matrix=Sink,Ind=AliveRowsSink,N=NoffspringSink)
                SpermSink<-gametes(matrix=Sink,Ind=AliveRowsSink,N=NoffspringSink)
                
                # Mating 
                if (AliveNumSink>1){    
                  if (Pself[j]==0){ 
                    ifelse (PollProb[y]==1,OCvec<-rep(B,AliveNumSink), OCvec<-rbinom(AliveNumSink,size=B,prob=PollProb[y]))
                    Sink<-MatingOC(sperm=SpermSink,egg=EggSink,Noc=OCvec,Ind=AliveRowsSink,ImmPoll=I[k],ImmSperm=SpermSource)
                  } else if (Pself[j]<1){
                    ifelse(PollProb[y]==1,OCvec<-rep(B,AliveNumSink), OCvec<-rbinom(AliveNumSink,size=B,prob=PollProb[y]))
                    NsfSink<-B-OCvec
                    SFvec<-rbinom(AliveNumSink,size=NsfSink,prob=Pself[j])
                    Sink<-MatingMX(sperm=SpermSink,egg=EggSink,Noc=OCvec,Nsf=SFvec,Ind=AliveRowsSink,ImmPoll=I[k],ImmSperm=SpermSource)
                  } else if (Pself[j]==1){
                    Sink<-MatingSF(sperm=SpermSink,egg=EggSink,Nsf=B,Ind=AliveRowsSink)
                  }
                } else if (AliveNumSink==1){
                  ifelse(Pself[j]>0,NocSink<-rbinom(1,size=B,prob=(PollProb[y]*I[k])),NocSink<-0)
                  NsfSink<-rbinom(1,size=(B-NocSink),prob=Pself[j])
                  Sink<-MatingSOLO(sperm=SpermSink,egg=EggSink,Noc=NocSink,Nsf=NsfSink,Ind=AliveRowsSink,ImmSperm=SpermSource)
                  if (mode(Sink)=="NULL") {
                    print(cat("Sink Extinction","Generation=",t,"Replicate=",r))
                    break
                  }
                } 
                
                # Mutations occur randomly on zygotes
                Sink<-Mutation(matrix=Sink)  
                Sink[,AliveCol]<-1
              }#t in sink
            }#t
          }#r
          
          ###########################################################################################
          ### Save Output csv files
          filePS<-paste("PopSize_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          fileGA<-paste("GenoAvg_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          fileGV<-paste("GenoVar_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          fileID<-paste("ID_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          fileOC<-paste("OC_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          fileSF<-paste("SF_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          fileTA<-paste("Tadapt_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
          
          write.csv(Output[,,1],quote=FALSE,row.names=FALSE,filePS)
          write.csv(Output[,,2],quote=FALSE,row.names=FALSE,fileGA)
          write.csv(Output[,,3],quote=FALSE,row.names=FALSE,fileGV)
          write.csv(Output[1,,6],quote=FALSE,row.names=FALSE,fileTA)
          write.csv(Output2[,,1],quote=FALSE,row.names=FALSE,fileID)
          write.csv(Output2[,,2],quote=FALSE,row.names=FALSE,fileOC)
          write.csv(Output2[,,3],quote=FALSE,row.names=FALSE,fileSF)
          
          if (sel[l]>0){
            fileMT<-paste("MutLoad_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
            fileMV<-paste("MutLoadVar_Theta",SinkTheta[q],"I",I[k],"P",PollProb[y],"s",sel[l],"H",dom[l],"C",NumCol,"L",NlociQT,"Alpha",alpha,"N",NlociID,"S",Pself[j],"ModeDelayed.csv",sep="")
            write.csv(Output[,,4],quote=FALSE,row.names=FALSE,fileMT)  
            write.csv(Output[,,5],quote=FALSE,row.names=FALSE,fileMV) 
          }  
          
          ##############################################################################################
          
        }#j
      }#k
    }#l
  }#q
}#y
T2<-proc.time()-T1
print(T2)
